"""HTML Parser using lxml.html

This file is a part of Bookmarks database and Internet robot.

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2010-2017 PhiloSoft Design"
__license__ = "GNU GPL"

__all__ = ['parse_html']


from lxml.html import fromtring
from .bkmk_ph_util import HTMLParser


def parse_html(html_text, charset=None, log=None):
    html_tree = fromtring(html_text)

    if html_tree.getroot() is None:
        return None

    title = html_tree.findtext('head/title')
    if title is None:
        title = html_tree.findtext('title')

    meta = html_tree.findall('head/meta')
    for m in meta:
        if m.get('http-equiv', '').lower() == 'content-type':
            meta_content = m.get("content")
            if meta_content:
                try:
                    meta_charset = \
                        meta_content.lower().split('charset=')[1].split(';')[0]
                    break
                except IndexError:
                    meta_charset = False
        elif m.get('charset', ''):
            meta_charset = m.get('charset').lower()
            break
    else:
        meta_charset = False

    if title and (charset or meta_charset):
        title = title.encode(charset or meta_charset)

    for m in meta:
        if m.get('http-equiv', '').lower() == 'refresh':
            refresh = m.get("content")
            break
    else:
        refresh = None

    for link in html_tree.findall('head/link'):
        if link.get('rel', '').lower() in ('icon', 'shortcut icon'):
            icon = link.get("href")
            break
    else:
        icon = None

    if (title is None) and (refresh is None) and (icon is None):
        return None
    return HTMLParser(charset, meta_charset, title, refresh, icon)
